#' opendatatoronto
#'
#' opendatatoronto is an R interface to the \href{https://open.toronto.ca/}{City of Toronto's Open Data Portal}.
#' The goal of the package is to help read data directly into R without needing
#' to manually download it via the portal.
#'
#' For more information, please start with the vignettes: \code{browseVignettes(package = "opendatatoronto")} or visit the \href{https://sharlagelfand.github.io/opendatatoronto/}{package website}.
#'
"_PACKAGE"

# Suppress R CMD check note
#' @importFrom readxl read_excel
#' @importFrom xml2 read_xml
NULL
